!
!  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
!  SLEPc - Scalable Library for Eigenvalue Problem Computations
!  Copyright (c) 2002-2017, Universitat Politecnica de Valencia, Spain
!
!  This file is part of SLEPc.
!  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
!  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
!
!  Single Fortran include file for all of SLEPc
!
#include "slepc/finclude/slepcsys.h"
#include "slepc/finclude/slepcbv.h"
#include "slepc/finclude/slepcfn.h"
#include "slepc/finclude/slepcds.h"
#include "slepc/finclude/slepcrg.h"
#include "slepc/finclude/slepcst.h"
#include "slepc/finclude/slepceps.h"
#include "slepc/finclude/slepcsvd.h"
#include "slepc/finclude/slepcpep.h"
#include "slepc/finclude/slepcnep.h"
#include "slepc/finclude/slepcmfn.h"
#include "slepc/finclude/slepclme.h"
